[![CI](https://github.com/EmadAlamoudi/libpetab-python-MS/actions/workflows/ci_tests.yml/badge.svg?branch=master)](https://github.com/EmadAlamoudi/libpetab-python-MS/actions/workflows/ci_tests.yml)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/fd7dd5cee68e449983be5c43f230c7f3)](https://www.codacy.com/gh/EmadAlamoudi/libpetab-python-MS)
[![codecov](https://codecov.io/gh/EmadAlamoudi/libpetab-python-MS/branch/master/graph/badge.svg)](https://codecov.io/gh/EmadAlamoudi/libpetab-python-MS)
[![PyPI version](https://badge.fury.io/py/petab.svg)](https://badge.fury.io/py/petab)

# petab_MS - a Python package for handling PEtab files for multiscale systems

PEtab_MS is an extension of PEtab for multiscale systems. [PEtab](https://petab.readthedocs.io/) is a data format for specifying
parameter estimation problems in systems biology. This repository provides
the `petab` Python package for reading, writing and validating PEtab files.


## Installation

The PEtab library is available on [pypi](https://pypi.org/project/petab-MS/)
and the easiest way to install it is running

    pip3 install petab_MS
    
It will require Python>=3.7.1 to run.

Development versions of the PEtab library can be installed using

    pip3 install https://github.com/EmadAlamoudi/libpetab-python-MS/archive/develop.zip
(replace `develop` by the branch or commit you would like to install).

## Getting help

If you have any question or problems with this package, feel free to post them
at our GitHub [issue tracker](https://github.com/EmadAlamoudi/libpetab-python-MS/issues/).

## Contributing

Contributions and feedback to this package are very welcome, see our
[contribution guide](CONTRIBUTING.md).
